@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.032-9-g2554cad
+package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.033-3-g6151582
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Add contributor names from git to your distribution
 # KEYWORDS: plugin distribution metadata git contributors authors commits
 
-our $VERSION = '0.033';
+our $VERSION = '0.034';
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider',
@@ -173,7 +173,10 @@ sub _build_contributors
 
     if (not $self->include_authors)
     {
-        my @author_emails = map { /(<[^>]+>)/g } @{ $self->zilla->authors };
+        my @authors = $self->zilla->authors;
+        @authors = @{ $authors[0] } if @authors == 1 && ref $authors[0];
+
+        my @author_emails = map { /(<[^>]+>)/g } @authors;
         @contributors = grep {
             my $contributor = $_;
             none { $contributor =~ /\Q$_\E/i } @author_emails;
@@ -264,7 +267,7 @@ Dist::Zilla::Plugin::Git::Contributors - Add contributor names from git to your
 
 =head1 VERSION
 
-version 0.033
+version 0.034
 
 =head1 SYNOPSIS
 
@@ -412,7 +415,7 @@ Karen Etheridge <ether@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Kent Fredric Ioan Rogers Klaus Eichner Matthew Horsfall Mohammad S Anwar
+=for stopwords Kent Fredric Matthew Horsfall Mohammad S Anwar Ricardo Signes Klaus Eichner Ioan Rogers
 
 =over 4
 
@@ -422,7 +425,15 @@ Kent Fredric <kentnl@cpan.org>
 
 =item *
 
-Ioan Rogers <ioan@dirtysoft.ca>
+Matthew Horsfall <wolfsage@gmail.com>
+
+=item *
+
+Mohammad S Anwar <mohammad.anwar@yahoo.com>
+
+=item *
+
+Ricardo Signes <rjbs@cpan.org>
 
 =item *
 
@@ -430,11 +441,7 @@ Klaus Eichner <klaus03@gmail.com>
 
 =item *
 
-Matthew Horsfall <wolfsage@gmail.com>
-
-=item *
-
-Mohammad S Anwar <mohammad.anwar@yahoo.com>
+Ioan Rogers <ioan@dirtysoft.ca>
 
 =back
 
